@@ -76,8 +76,8 @@ class attributes:
                                                       weight=self.legend_weight,
                                                       style=self.legend_style,
                                                       size=self.legend_size)
-            self.ax.legend(loc=self.legend_loc, prop=legend_font,
-                           handleheight=self.legend_handleheight, ncol=self.legend_ncol)
+            self.legend = self.fig.legend(loc=self.legend_loc, prop=legend_font,
+                                          handleheight=self.legend_handleheight, ncol=self.legend_ncol)
 
     def method_title(self):
         if not isinstance(self.title, type(None)):
