@@ -177,9 +177,10 @@ class attributes:
                                                       weight=self.legend_weight,
                                                       style=self.legend_style,
                                                       size=self.legend_size)
-            self.fig.legend(lines, labels,
-                            loc=self.legend_loc, prop=legend_font,
-                            handleheight=self.legend_handleheight, ncol=self.legend_ncol)
+            self.legend = self.fig.legend(lines, labels,
+                                          loc=self.legend_loc,
+                                          bbox_to_anchor=self.legend_bbox_to_anchor, prop=legend_font,
+                                          handleheight=self.legend_handleheight, ncol=self.legend_ncol)
 
     def method_resize_axes(self):
 
@@ -291,33 +292,29 @@ class attributes:
         for spine in self.ax.spines.values():
             spine.set_color(self.workspace_color if isinstance(self.spine_color, type(None)) else self.spine_color)
 
-        top = True
-        right = True
-        left = True
-        bottom = True
-
         if not isinstance(self.spines_removed, type(None)):
             for spine in self.spines_removed:
-                self.ax.spines[spine].set_visible(False)
-                if spine == 'top':
-                    top = False
-                if spine == 'bottom':
-                    bottom = False
-                if spine == 'left':
-                    left = False
-                if spine == 'right':
-                    right = False
+                self.ax.spines[["left", "bottom", "top", "right"][spine]].set_visible(False)
 
-        self.ax.tick_params(axis='both', which='both', top=top, right=right, left=left, bottom=bottom)
+        # Axis ticks
+        left, bottom, top, right = self.ticks_where
+        # Tick labels
+        labelleft, labelbottom, labeltop, labelright = self.tick_labels_where
+
+        self.ax.tick_params(axis='both', which='both',
+                            top=top, right=right, left=left, bottom=bottom,
+                            labeltop=labeltop, labelright=labelright, labelleft=labelleft, labelbottom=labelbottom)
 
     def method_ticks(self):
         """
         Defaults
         """
+        if np.all(self.y == self.y[0]):
+            self.fine_tick_locations = False
         if self.fine_tick_locations is True:
-            if not isinstance(self.x, type(None)):
+            if not isinstance(self.x, type(None)) and isinstance(self.custom_x_tick_locations, type(None)):
                 self.custom_x_tick_locations = [self.x.min(), self.x.max()]
-            if not isinstance(self.y, type(None)):
+            if not isinstance(self.y, type(None)) and isinstance(self.custom_y_tick_locations, type(None)):
                 self.custom_y_tick_locations = [self.y.min(), self.y.max()]
         """
         Implementation
@@ -553,7 +550,7 @@ class line(plot, std_input):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -576,6 +573,7 @@ class line(plot, std_input):
                  y_tick_number=5, y_tick_labels=None,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
@@ -583,6 +581,7 @@ class line(plot, std_input):
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
                  x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
                  color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
                  cb_title=None, cb_orientation='vertical',
@@ -592,7 +591,8 @@ class line(plot, std_input):
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
                  show=False, zorder=None,
@@ -669,7 +669,7 @@ class scatter(plot, std_input):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -692,6 +692,7 @@ class scatter(plot, std_input):
                  y_tick_number=5, y_tick_labels=None,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
@@ -699,6 +700,7 @@ class scatter(plot, std_input):
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
                  x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
                  color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
                  cb_title=None, cb_orientation='vertical',
@@ -708,7 +710,8 @@ class scatter(plot, std_input):
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
                  show=False, zorder=None,
@@ -773,7 +776,7 @@ class heatmap(plot, df_input):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -796,6 +799,7 @@ class heatmap(plot, df_input):
                  y_tick_number=5, y_tick_labels=None,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
@@ -803,6 +807,7 @@ class heatmap(plot, df_input):
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
                  x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
                  color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
                  cb_title=None, cb_orientation='vertical',
@@ -812,7 +817,8 @@ class heatmap(plot, df_input):
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
                  show=False, zorder=None,
@@ -882,7 +888,7 @@ class quiver(plot, std_input):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -905,6 +911,7 @@ class quiver(plot, std_input):
                  y_tick_number=5, y_tick_labels=None,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
@@ -912,6 +919,7 @@ class quiver(plot, std_input):
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
                  x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
                  color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
                  cb_title=None, cb_orientation='vertical',
@@ -921,7 +929,8 @@ class quiver(plot, std_input):
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
                  show=False, zorder=None,
@@ -1009,7 +1018,7 @@ class streamline(plot, std_input):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -1032,6 +1041,7 @@ class streamline(plot, std_input):
                  y_tick_number=5, y_tick_labels=None,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
@@ -1039,6 +1049,7 @@ class streamline(plot, std_input):
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
                  x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
                  color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
                  cb_title=None, cb_orientation='vertical',
@@ -1048,7 +1059,8 @@ class streamline(plot, std_input):
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
                  show=False, zorder=None,
@@ -1124,7 +1136,7 @@ class fill_area(plot, std_input):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -1147,6 +1159,7 @@ class fill_area(plot, std_input):
                  y_tick_number=5, y_tick_labels=None,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
@@ -1154,6 +1167,7 @@ class fill_area(plot, std_input):
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
                  x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
                  color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
                  cb_title=None, cb_orientation='vertical',
@@ -1163,7 +1177,8 @@ class fill_area(plot, std_input):
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
                  show=False, zorder=None,
